@@ -8,5 +8,7 @@
 
 # setwd("tests/testthat")
 
-get_data_location <- function(x)
+get_data_location <- function(x){
+  # here::here(file.path("tests","testthat","data", x))
   file.path("data", x)
+}
